# eric7.MultiProject.MultiProjectProjectMeta

Module defining a class containing the individual project metadata.

### Global Attributes

None

### Classes

MultiProjectProjectMeta | Class containing the individual project metadata.

### Functions

None

## MultiProjectProjectMeta

Class containing the individual project metadata.

### Derived from

None

### Class Attributes

category
description
file
main
name
removed
uid

### Class Methods

from_dict | Class method to create a metadata object from the given dictionary.

### Methods

as_dict | Public method to convert the metadata into a dictionary.

### Static Methods

None

#### MultiProjectProjectMeta.from_dict (class method)

from_dict(data)

Class method to create a metadata object from the given dictionary.

data (dict)
  dictionary containing the metadata

Return:
  created project metadata object

Return Type:
  MultiProjectProjectMeta

#### MultiProjectProjectMeta.as_dict

as_dict()

Public method to convert the metadata into a dictionary.

Return:
  dictionary containing the metadata

Return Type:
  dict

Up